<?php

namespace Drupal\Tests\unified_date\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\node\Traits\NodeCreationTrait;

/**
 * Unified date test base field existance.
 *
 * @group unified_date
 */
class UnifiedDateBasefieldTest extends KernelTestBase {

  use NodeCreationTrait;

  /**
   * The modules to enable for this test.
   *
   * @var array
   */
  protected static $modules = [
    'node',
    'field',
    'user',
    'system',
    'unified_date',
  ];

  /**
   * The current database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The cron service.
   *
   * @var \Drupal\Core\Cron
   */
  protected $cron;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installSchema('node', ['node_access']);
    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installConfig(['field']);

    // Create article content type.
    NodeType::create([
      'type' => 'article',
      'name' => 'Article',
    ])->save();

    // Inject database connection, entity type manager and cron for the tests.
    $this->database = \Drupal::database();
    $this->entityTypeManager = \Drupal::entityTypeManager();
    $this->cron = \Drupal::service('cron');
  }

  /**
   * Test the render method when getEntity returns NULL.
   *
   * @covers ::render
   */
  public function testBasefield(): void {
    $node = $this->createNode([
      'title' => t('Hello, world!'),
      'type' => 'article',
    ]);
    $unified_date_value = $node->get('unified_date')->value;

    // By default the unified_date field should match the created time.
    $this->assertNotEmpty($unified_date_value);
    $this->assertSame($unified_date_value, $node->getCreatedTime());
  }

}
